@@ -297,7 +297,6 @@ class Task(object):
         os.chdir(self.dir)
 
         self.proc = await asyncio.create_subprocess_shell( cmd, stdout=asyncio.subprocess.PIPE, stderr=asyncio.subprocess.PIPE)
-        log.info(cmd.replace(env_rnd, ''))
         await asyncio.gather(watch(self.proc.stdout, '[stdout]'), watch(self.proc.stderr, '[stderr]'))
 
         await self.proc.wait()
@@ -401,6 +400,7 @@ class SequentialTaskList(TaskList):
 #                        pprint(vars(run_task))
                     if isinstance(run_task, Task):
                         run_task.cmd = run_task.cmd.format(**self.vars)
+                        log.info(run_task.cmd)
                     if self.kill:
                         break
                     self.current = run_task
